--
-- InteractiveButtons
-- Specialization for an interactive control button
--
-- @author  	Manuel Leithner (SFM-Modding)
-- @version 	v2.0
-- @date  		15/10/10
-- @history:	v1.0 - Initial version
--				v2.0 - converted to ls2011
--

InteractiveButtons = {};

function InteractiveButtons.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations);
end;

function InteractiveButtons:load(xmlFile)

	self.count = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.interactiveComponents.buttons#count"), 0);	
	if self.count ~= 0 then	
		for i=1, self.count do	
			local buttonName = string.format("vehicle.interactiveComponents.buttons.button%d", i);	
			local name = Utils.getNoNil(g_i18n:getText(getXMLString(xmlFile, buttonName .. "#name")), "ERROR");
			local mark = Utils.indexToObject(self.components, getXMLString(xmlFile, buttonName .. "#mark"));
			local highlight = getChildAt(mark, 0);
			local size = Utils.getNoNil(getXMLFloat(xmlFile, buttonName .. "#size"), 0.1);
			local event = getXMLString(xmlFile, buttonName .. "#event");
			local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#onMessage"), "ic_button_on"));
			local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#offMessage") , "ic_button_off"));
		
			local button = Button:new(nil, highlight, name, mark, size, event, self, onMessage, offMessage);

			table.insert(self.interactiveObjects, button);
		end;
	end;
	
end;

function InteractiveButtons:delete()
end;

function InteractiveButtons:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveButtons:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveButtons:update(dt)	
end;

function InteractiveButtons:draw()
end;



--
-- Button Class
-- Specifies an interactive Button
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  25/12/09
--

Button = {};

function Button:new(node, highlight, name, mark, size, event, vehicle, onMessage, offMessage)

	local Button_mt = Class(Button, InteractiveComponentInterface);	
    local instance = InteractiveComponentInterface:new(node, highlight, name, mark, size, g_i18n:getText("ic_button_on"), g_i18n:getText("ic_button_off"), Button_mt);

	instance.vehicle = vehicle;
	instance.event = event;
	
	return instance;	
end;

function Button:delete()
	InteractiveComponentInterface.delete(self);
end;

function Button:mouseEvent(posX, posY, isDown, isUp, button)
	InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Button:keyEvent(unicode, sym, modifier, isDown)
	InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Button:update(dt)
	if self.event == "toggleWorkingLightFront" then	
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.B3["work"][1].a;
		end;
	end;
	if self.event == "toggleWorkingLightRear" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.B3["work"][2].a;
		end;
	end;
	if self.event == "toggleLights" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.Lights;
		end;
	end;
	if self.event == "toggleBeaconLights" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.beaconLightsActive;
		end;
	end;
	if self.event == "toggleMotorIgnition" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.isMotorStarted;
		end;
	end;
	if self.event == "toggleRadio" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.RadioOn;
		end;
	end;
	if self.event == "toggleFunk" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.FunkOn;
		end;
	end;
	if self.event == "toggleCabLights" then
		if self.vehicle ~= nil then
			self.isOpen = self.vehicle.B3["work"][7].a;
		end;
	end;
	
	InteractiveComponentInterface.update(self, dt);
end;

function Button:draw()
	InteractiveComponentInterface.draw(self);
end;

function Button:doAction(noEventSend, forceAction)
	if self.event == "toggleWorkingLightFront" then	
		if self.vehicle ~= nil then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];	
				self.vehicle:setState("work:1", not lt[1].a, true);
			else
				self.vehicle:setState("work:1", forceAction, true);
			end;
		end;
		if forceAction == nil then
			local lt = self.vehicle.B3["work"];			
			self.vehicle:setState("work:3", not lt[3].a, true);
		else
			self.vehicle:setState("work:3", forceAction, true);
		end;
	end;
	if self.event == "toggleWorkingLightRear" then
		if self.vehicle ~= nil then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];			
				self.vehicle:setState("work:2", not lt[2].a, true);
			else
				self.vehicle:setState("work:2", forceAction, true);
			end;
		end;
		if forceAction == nil then
			local lt = self.vehicle.B3["work"];			
			self.vehicle:setState("work:4", not lt[4].a, true);
		else
			self.vehicle:setState("work:4", forceAction, true);
		end;
	end;
	if self.event == "toggleLights" then
		if self.vehicle ~= nil then
			if self.vehicle.lightsActive then
				self.vehicle:setLightsVisibility(false);
			else
				self.vehicle:setLightsVisibility(true);
			end;
		end;
	end;
	if self.event == "toggleBeaconLights" then
		if self.vehicle ~= nil then
			self.vehicle:setBeaconLightsVisibility(not self.vehicle.beaconLightsActive);
		end;
	end;
	if self.event == "toggleMotorIgnition" then
		if self.vehicle.isMotorStarted then
			self.vehicle:invokeIgnition(false, noEventSend);
		else
			self.vehicle:invokeIgnition(true, noEventSend);
		end;
		if forceAction == nil then
			local lt = self.vehicle.B3["work"];			
			self.vehicle:setState("work:5", not lt[5].a, true);
		else
			self.vehicle:setState("work:5", forceAction, true);
		end;
	end;
	if self.event == "toggleRadio" then
		if self.vehicle ~= nil then
			if self.vehicle.RadioOn then
				self.vehicle.RadioOn = false;
			else
				self.vehicle.RadioOn = true;
			end;
		end;	
		if forceAction == nil then
			local lt = self.vehicle.B3["work"];			
			self.vehicle:setState("work:6", not lt[6].a, true);
		else
			self.vehicle:setState("work:6", forceAction, true);
		end;
	end;
	if self.event == "toggleFunk" then
		if self.vehicle ~= nil then
			if self.vehicle.FunkOn then
				self.vehicle.FunkOn = false;
			else
				self.vehicle.FunkOn = true;
			end;
		end;	
	end;
	if self.event == "toggleCabLights" then
		if self.vehicle ~= nil then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];			
				self.vehicle:setState("work:7", not lt[7].a, true);
			else
				self.vehicle:setState("work:7", forceAction, true);
			end;
		end;
	end;
	
end;

function Button:onEnter(dt)
	InteractiveComponentInterface.onEnter(self, dt);
end;

function Button:onExit(dt)
	InteractiveComponentInterface.onExit(self, dt);
end;

function Button:setActive()
	InteractiveComponentInterface.setActive(self, isActive);
end;

function Button:setVisible(isVisible)
	InteractiveComponentInterface.setVisible(self, isVisible);
end;